@@ -82,7 +82,7 @@ var brokerConfigRoot = "/amq/init/config"
 
 //default ApplyRule for address-settings
 var defApplyRule string = "merge_all"
-var yacfgProfileVersion = version.LatestVersion
+var yacfgProfileVersion = version.YacfgProfileVersionFromFullVersion[version.LatestVersion]
 
 type ActiveMQArtemisReconciler struct {
 	statefulSetUpdates uint32
@@ -130,6 +130,8 @@ func (reconciler *ActiveMQArtemisReconciler) Process(fsm *ActiveMQArtemisFSM, cl
 
 func (reconciler *ActiveMQArtemisReconciler) ProcessStatefulSet(fsm *ActiveMQArtemisFSM, client client.Client, log logr.Logger, firstTime bool) (*appsv1.StatefulSet, bool) {
 
+	statefulsetRecreationRequired := false
+
 	ssNamespacedName := types.NamespacedName{
 		Name:      ss.NameBuilder.Name(),
 		Namespace: fsm.customResource.Namespace,
@@ -139,9 +141,47 @@ func (reconciler *ActiveMQArtemisReconciler) ProcessStatefulSet(fsm *ActiveMQArt
 		log.Info("StatefulSet: " + ssNamespacedName.Name + " not found, will create")
 		currentStatefulSet = NewStatefulSetForCR(fsm.customResource)
 		firstTime = true
-	} else {
-		log.Info("StatefulSet: " + currentStatefulSet.Name + " found")
+	} else if nil == err {
+		// Found it
+		log.Info("StatefulSet: " + ssNamespacedName.Name + " found")
+		log.Info("Checking for statefulset and current operator compatibility")
+		log.V(1).Info("Checking owner apiVersion")
+		objectMetadata := currentStatefulSet.GetObjectMeta()
+		log.V(1).Info(fmt.Sprintf("ObjectMetadata: %s", objectMetadata))
+		ownerReferenceArray := objectMetadata.GetOwnerReferences()
+		log.V(1).Info(fmt.Sprintf("ownerReferenceArray: %s", ownerReferenceArray))
+		if 0 < len(ownerReferenceArray) {
+			// got at least one owner
+			log.V(1).Info("ownerReferenceArray has at least one owner")
+			log.V(1).Info(fmt.Sprintf("ownerReference[0].APIVersion: %s", ownerReferenceArray[0].APIVersion))
+			if "broker.amq.io/v2alpha4" != ownerReferenceArray[0].APIVersion {
+				// nuke it and recreate
+				log.V(1).Info(fmt.Sprintf("ownerReference[0].APIVersion: %s - removing in favour of upgraded v2alpha4", ownerReferenceArray[0].APIVersion))
+				log.Info("Statefulset recreation required for current operator compatibility")
+				statefulsetRecreationRequired = true
+			}
+		}
+		log.V(1).Info("Checking statefulset for CONFIG_INSTANCE_DIR existence")
+		configInstanceDirEnvVar := environments.Retrieve(currentStatefulSet.Spec.Template.Spec.Containers, "CONFIG_INSTANCE_DIR")
+		if nil == configInstanceDirEnvVar {
+			log.Info("CONFIG_INSTANCE_DIR environment variable NOT found, ensuring existing statefulset operator compatibility")
+			log.Info("Statefulset recreation required for current operator compatibility")
+			statefulsetRecreationRequired = true
+		}
+		if statefulsetRecreationRequired {
+			log.Info("Recreating existing statefulset")
+			deleteErr := resources.Delete(ssNamespacedName, client, currentStatefulSet)
+			if nil == deleteErr {
+				log.Info(fmt.Sprintf("sucessfully deleted ownerReference[0].APIVersion: %s, recreating v2alpha4 version for use", ownerReferenceArray[0].APIVersion))
+				currentStatefulSet = NewStatefulSetForCR(fsm.customResource)
+				firstTime = true
+			} else {
+				log.Info("statefulset recreation failed!")
+			}
+		}
+
 		//update statefulset with customer resource
+		log.Info("Calling ProcessAddressSettings")
 		if reconciler.ProcessAddressSettings(fsm.customResource, fsm.prevCustomResource, client) {
 			log.Info("There are new address settings change in the cr, creating a new pod template to update")
 			*fsm.prevCustomResource = *fsm.customResource
@@ -1659,7 +1699,7 @@ func NewPodTemplateSpecForCR(customResource *brokerv2alpha4.ActiveMQArtemis) cor
 		outputDir := "/yacfg_etc"
 
 		compactVersionToUse := determineCompactVersionToUse(customResource)
-		yacfgProfileVersion = version.FullVersionFromCompactVersion[compactVersionToUse]
+		yacfgProfileVersion = version.YacfgProfileVersionFromFullVersion[version.FullVersionFromCompactVersion[compactVersionToUse]]
 		yacfgProfileName := version.YacfgProfileName
 
 		initCmd := "echo \"" + configYaml.String() + "\" > " + outputDir +
